@@ -74,23 +74,24 @@ func New() (cmd *cobra.Command) {
 }
 
 func run(ctx context.Context) error {
-
 	appConfig, err := determineAppConfig(ctx)
 	if err != nil {
 		return err
 	}
 
 	return DeployWithConfig(ctx, appConfig)
-
 }
 
 func DeployWithConfig(ctx context.Context, appConfig *app.Config) (err error) {
-
 	apiClient := client.FromContext(ctx).API()
 
+	// Assign an empty map if nil so later assignments won't fail
+	if appConfig.Env == nil {
+		appConfig.Env = map[string]string{}
+	}
+
 	// Fetch an image ref or build from source to get the final image reference to deploy
 	img, err := determineImage(ctx, appConfig)
-
 	if err != nil {
 		return fmt.Errorf("failed to fetch an image or build from source: %w", err)
 	}
@@ -99,19 +100,18 @@ func DeployWithConfig(ctx context.Context, appConfig *app.Config) (err error) {
 		return nil
 	}
 
-	if err != nil {
-		return err
-	}
-
 	var release *api.Release
 	var releaseCommand *api.ReleaseCommand
 
-	if appConfig.ForMachines() {
-		return createMachinesRelease(ctx, appConfig, img, flag.GetString(ctx, "strategy"))
-	} else {
-		release, releaseCommand, err = createRelease(ctx, appConfig, img)
+	if appConfig.PrimaryRegion != "" && appConfig.Env["PRIMARY_REGION"] == "" {
+		appConfig.Env["PRIMARY_REGION"] = appConfig.PrimaryRegion
 	}
 
+	if appConfig.ForMachines() {
+		return createMachinesRelease(ctx, appConfig, img, flag.GetString(ctx, "strategy"))
+	}
+
+	release, releaseCommand, err = createRelease(ctx, appConfig, img)
 	if err != nil {
 		return err
 	}
@@ -147,7 +147,7 @@ func DeployWithConfig(ctx context.Context, appConfig *app.Config) (err error) {
 		return nil
 	}
 
-	err = watch.Deployment(ctx, release.EvaluationID)
+	err = watch.Deployment(ctx, app.NameFromContext(ctx), release.EvaluationID)
 
 	return err
 }
@@ -168,7 +168,6 @@ func determineAppConfig(ctx context.Context) (cfg *app.Config, err error) {
 		}
 
 		basicApp, err := client.GetAppBasic(ctx, app.NameFromContext(ctx))
-
 		if err != nil {
 			return nil, err
 		}
@@ -188,12 +187,14 @@ func determineAppConfig(ctx context.Context) (cfg *app.Config, err error) {
 
 			return
 		}
-
 		cfg.SetEnvVariables(parsedEnv)
 	}
 
-	tb.Done("Verified app config")
+	if regionCode := flag.GetString(ctx, flag.RegionName); regionCode != "" {
+		cfg.PrimaryRegion = regionCode
+	}
 
+	tb.Done("Verified app config")
 	return
 }
 
@@ -253,7 +254,6 @@ func determineImage(ctx context.Context, appConfig *app.Config) (img *imgsrc.Dep
 	}
 
 	cliBuildSecrets, err := cmdutil.ParseKVStringsToMap(flag.GetStringSlice(ctx, "build-secret"))
-
 	if err != nil {
 		return
 	}
@@ -311,7 +311,6 @@ func resolveDockerfilePath(ctx context.Context, appConfig *app.Config) (path str
 }
 
 func mergeBuildArgs(ctx context.Context, args map[string]string) (map[string]string, error) {
-
 	if args == nil {
 		args = make(map[string]string)
 	}
